@@ -3,11 +3,15 @@ package Unicode::Util;
 use 5.008;
 use strict;
 use warnings;
+use utf8;
 use parent 'Exporter';
 use Encode qw( encode_utf8 );
 
-our $VERSION     = '0.01';
-our @EXPORT_OK   = qw( graph_length code_length byte_length );
+our $VERSION   = '0.02';
+our @EXPORT_OK = qw(
+    graph_length code_length byte_length
+    graph_chop   code_chop
+);
 our %EXPORT_TAGS = ( all => \@EXPORT_OK );
 
 sub graph_length {
@@ -28,6 +32,19 @@ sub byte_length {
     return length encode_utf8($str);
 }
 
+sub graph_chop {
+    my $str = \$_[0];
+    utf8::upgrade($$str);
+    $$str =~ s/(\X)$//;
+    return $1;
+}
+
+sub code_chop {
+    my $str = \$_[0];
+    utf8::upgrade($$str);
+    return chop $$str;
+}
+
 1;
 
 __END__
@@ -40,13 +57,13 @@ Unicode::Util - Unicode-aware versions of built-in Perl functions
 
 =head1 VERSION
 
-This document describes Unicode::Util version 0.01.
+This document describes Unicode::Util version 0.02.
 
 =head1 SYNOPSIS
 
-    use Unicode::Util;
+    use Unicode::Util qw( graph_length code_length byte_length );
 
-    # grapheme cluster: Cyrillic small letter yu + combining acute accent
+    # grapheme cluster ю́: Cyrillic small letter yu + combining acute accent
     my $grapheme = "\x{44E}\x{301}";
 
     say graph_length($grapheme);  # 1
@@ -55,21 +72,21 @@ This document describes Unicode::Util version 0.01.
 
 =head1 DESCRIPTION
 
-This module provides additional versions of Perl's built-in functions,
+This module provides additional versions of Perl’s built-in functions,
 tailored to work on three different units:
 
 =over
 
-=item Unicode extended grapheme clusters (graphemes)
+=item * graph: Unicode extended grapheme clusters (graphemes)
 
-=item Unicode code points
+=item * code: Unicode codepoints
 
-=item bytes (octets)
+=item * byte: 8-bit bytes (octets)
 
 =back
 
 This is an early release and this module is likely to have major revisions.
-Only the C<length> functions are currently implemented.  See the L</TODO>
+Only the C<length>-functions are currently implemented.  See the L</TODO>
 section for planned future additions.
 
 =head1 FUNCTIONS
@@ -79,13 +96,13 @@ section for planned future additions.
 =item graph_length($string)
 
 Returns the length in graphemes of the given string.  This is likely the
-number of "characters" that many people would count on a printed string, plus
+number of “characters” that many people would count on a printed string, plus
 non-printing characters.
 
 =item code_length($string)
 
-Returns the length in code points of the given string.  This is likely the
-number of "characters" that many programmers and programming languages would
+Returns the length in codepoints of the given string.  This is likely the
+number of “characters” that many programmers and programming languages would
 count in a string.
 
 =item byte_length($string)
@@ -93,16 +110,29 @@ count in a string.
 Returns the length in bytes of the given string encoded as UTF-8.  This is the
 number of bytes that many computers would count when storing a string.
 
+=item graph_chop($string)
+
+Chops off the last grapheme of the given string and returns the grapheme
+chopped.
+
+=item code_chop($string)
+
+Chops off the last codepoint of the given string and returns the codepoint
+chopped.
+
 =back
 
 =head1 TODO
 
-graph_reverse graph_chop graph_split graph_substr code_substr byte_substr
-graph_index code_index byte_index graph_rindex code_rindex byte_rindex
+Evaluate the following core Perl functions and operators for the potential
+addition to this module.
+
+C<reverse>, C<split>, C<substr>, C<index>, C<rindex>,
+C<eq>, C<ne>, C<lt>, C<gt>, C<le>, C<ge>, C<cmp>
 
 =head1 SEE ALSO
 
-The C<length> functions are based on methods provided by L<Perl6::Str>.
+The C<length>-functions are based on methods provided by L<Perl6::Str>.
 
 =head1 AUTHOR
 
